==> ejc-sddjsorg-api-3.0.0-20211012.084716-4-sources.jar: com/ejianc/business/orgcenter/vo/AdministrativeAreaVO.java <==
package com.ejianc.business.orgcenter.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.List;

/**
 * 行政地区数据实体
 *
 * @author CJ
 * @Description:
 * @date 2021/10/12 10:44
 */
public class AdministrativeAreaVO extends BaseVO {
    private static final long serialVersionUID = 3821909844890847072L;

    /**
     * 行政地区编码
     */
    private String BillCode;

    /**
     * 行政地区名称
     */
    private String areaName;

    /**
     * 状态：0-停用，1-启用
     */
    private Integer status;

    /**
     * 行政地区登记
     */
    private Integer level;

    /**
     * 上级行政地区Id
     */
    private Long pid;

    /**
     * 上级行政地区名称
     */
    private String pName;

    /**
     * 子级行政地区
     */
    private List<AdministrativeAreaVO> children;

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getLevel() {
        return level;
    }

    public void setLevel(Integer level) {
        this.level = level;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getpName() {
        return pName;
    }

    public void setpName(String pName) {
        this.pName = pName;
    }

    public List<AdministrativeAreaVO> getChildren() {
        return children;
    }

    public void setChildren(List<AdministrativeAreaVO> children) {
        this.children = children;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211021.075752-43-sources.jar: com/ejianc/business/orgcenter/vo/AdministrativeAreaVO.java <==
package com.ejianc.business.orgcenter.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 行政地区数据实体
 *
 * @author CJ
 * @Description:
 * @date 2021/10/12 10:44
 */
public class AdministrativeAreaVO extends BaseVO {
    public static final Integer STATUS_VALID = 1;
    public static final Integer STATUS_INVALID = 0;
    private static final long serialVersionUID = 3821909844890847072L;

    /**
     * 行政地区编码
     */
    private String BillCode;

    /**
     * 行政地区名称
     */
    private String areaName;

    /**
     * 状态：0-停用，1-启用
     */
    private Integer status;

    /**
     * 行政地区登记
     */
    private Integer level;

    /**
     * 上级行政地区Id
     */
    private Long pid;

    /**
     * 上级行政地区名称
     */
    private String pName;

    /**
     * 子级行政地区
     */
    private List<AdministrativeAreaVO> children = new ArrayList<>();

    /**
     * 描述
     */
    private String description;

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getLevel() {
        return level;
    }

    public void setLevel(Integer level) {
        this.level = level;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getpName() {
        return pName;
    }

    public void setpName(String pName) {
        this.pName = pName;
    }

    public List<AdministrativeAreaVO> getChildren() {
        return children;
    }

    public void setChildren(List<AdministrativeAreaVO> children) {
        this.children = children;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}
